@@ -47,12 +47,13 @@
 ena.conversations = function(set, units, units.by=NULL, codes=NULL, conversation.by = NULL, window = 4, conversation.exclude = c()) {
   # rawData = data.table::copy(set$enadata$raw);
   if(is.null(units.by)) {
-    units.by = set$enadata$function.params$units.by;
+    # units.by = set$enadata$function.params$units.by;
+    units.by = set$function.params$units.by;
   }
   # conversation.by = set$enadata$function.params$conversations.by;
   # window = set$enadata$function.params$window.size.back;
   # rawAcc = data.table::copy(set$enadata$accumulated.adjacency.vectors);
-    rawAcc2 = data.table::data.table(set); #set$enadata$raw);
+    rawAcc2 = data.table::data.table(set) #$enadata$raw);
 
   # rawAcc$KEYCOL = merge_columns_c(rawAcc, conversation.by)
   rawAcc2$KEYCOL = merge_columns_c(rawAcc2, conversation.by)
@@ -61,8 +62,8 @@ ena.conversations = function(set, units, units.by=NULL, codes=NULL, conversation
   conversationsTable2 = rawAcc2[, paste(.I, collapse = ","), by = c(conversation.by)]
 
   # rows = sapply(conversationsTable$V1, function(x) as.numeric(unlist(strsplit(x, split=","))),USE.NAMES = T)
-  rows2 = sapply(conversationsTable2$V1, function(x) as.numeric(unlist(strsplit(x, split=","))),USE.NAMES = T)
-
+  rows2 = lapply(conversationsTable2$V1, function(x) as.numeric(unlist(strsplit(x, split=","))))
+  # browser()
   # names(rows) = merge_columns_c(conversationsTable,conversation.by); #unique(rawAcc[,KEYCOL])
   names(rows2) = merge_columns_c(conversationsTable2,conversation.by); #unique(rawAcc[,KEYCOL])
 
@@ -81,18 +82,26 @@ ena.conversations = function(set, units, units.by=NULL, codes=NULL, conversation
 
   # codedUnitRowConvsAll = NULL;
   codedUnitRowConvsAll2 = NULL;
+  unitRowsNotCooccurred = c()
   if(length(codedUnitRows2) > 0) {
     codedUnitRowConvsAll = unique(unlist(sapply(X = 1:length(codedUnitRows2), simplify = F, FUN = function(x) {
       thisConvRows = rows2[[codedUnitRowConvs2[x]]]
       thisRowInConv = which(thisConvRows == codedUnitRows2[x])
       thisRowAndWindow = rep(thisRowInConv,window) - (window-1):0;
-      thisConvRows[thisRowAndWindow[thisRowAndWindow > 0]]
+      coOccursFound = all(rawAcc2[thisConvRows[thisRowAndWindow[thisRowAndWindow > 0]], lapply(.SD, sum), .SDcols=codes] > 0)
+      if(coOccursFound) {
+        thisConvRows[thisRowAndWindow[thisRowAndWindow > 0]]
+      } else {
+        unitRowsNotCooccurred <<- c(unitRowsNotCooccurred, thisConvRows[thisRowInConv])
+        coOccursFound
+      }
     })))
   }
   return(list(
-    conversations = rows2,
+    conversations = as.list(rows2),
     unitConvs = unique(rawAcc2[codedUnitRows2,KEYCOL]),
     allRows = codedUnitRowConvsAll,
-    unitRows = codedUnitRows2
+    unitRows = codedUnitRows2,
+    toRemove = unitRowsNotCooccurred
   ));
 }
